============================
 Aloe: BDD testing via nose
============================

Aloe is a Gherkin_-based Behavior Driven Development tool for Python based
on Nose_.

.. toctree::
    :maxdepth: 2

    aloe
    features
    steps
    hooks
    classes
    extras
    extending
    porting

.. include:: getting-started.rst


History
=======

`Aloe` originally started life as a branch of the Python BDD tool Lettuce_.
Like so many succulents, it grew into so much more than that.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: links.rst
